@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11861 2020-01-14 12:00:19Z Lavender $
+# $Id: models.py 12819 2021-03-30 02:12:19Z Becca $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Lavender $ (last)
-# $Date: 2020-01-14 20:00:19 +0800 (Tue, 14 Jan 2020) $
-# $Revision: 11861 $
+# $Author: Becca $ (last)
+# $Date: 2021-03-30 10:12:19 +0800 (週二, 30 三月 2021) $
+# $Revision: 12819 $
 
 from django.db import models
 from django.utils.translation import ugettext as _
@@ -94,6 +94,36 @@ class OscarLatest(CMSPlugin):
             "If no choice. It will not filter product by category.")
     )
 
+class OscarBestSeller(CMSPlugin):
+    limit = models.PositiveIntegerField(default=6)
+
+    filterMethod = models.IntegerField(
+        _('Filter Method'), choices=METHODS, default=OR)
+
+    renderTemplate = models.CharField(
+        'BestSeller Template', max_length=150, blank=True,
+        choices=settings.ZEPHYRUS_OSCAR_BESTSELLER_TEMPLATES,
+        default=settings.ZEPHYRUS_OSCAR_BESTSELLER_DEFAULT_TEMPLATE,
+    )
+    
+    tag = models.CharField(
+        max_length=200,
+        default=None,
+        blank=True,
+        null=True,
+        help_text=_(
+            "If no choice. It will not filter product by tag.")
+    )
+
+    catagory = models.ManyToManyField(
+        Category,
+        blank=True,
+        null=True,
+        help_text=_(
+            "If no choice. It will not filter product by category.")
+    )
+
+
 class OscarOffer(CMSPlugin):
     limit = models.PositiveIntegerField(default=6)
 
